import { AwsSdkSigV4AuthInputConfig, AwsSdkSigV4AuthResolvedConfig, AwsSdkSigV4PreviouslyResolved } from "@aws-sdk/core";
import { HandlerExecutionContext, HttpAuthScheme, HttpAuthSchemeParameters, HttpAuthSchemeParametersProvider, HttpAuthSchemeProvider } from "@smithy/types";
import { ImagebuilderClientResolvedConfig } from "../ImagebuilderClient";
/**
 * @internal
 */
export interface ImagebuilderHttpAuthSchemeParameters extends HttpAuthSchemeParameters {
    region?: string;
}
/**
 * @internal
 */
export interface ImagebuilderHttpAuthSchemeParametersProvider extends HttpAuthSchemeParametersProvider<ImagebuilderClientResolvedConfig, HandlerExecutionContext, ImagebuilderHttpAuthSchemeParameters, object> {
}
/**
 * @internal
 */
export declare const defaultImagebuilderHttpAuthSchemeParametersProvider: (config: ImagebuilderClientResolvedConfig, context: HandlerExecutionContext, input: object) => Promise<ImagebuilderHttpAuthSchemeParameters>;
/**
 * @internal
 */
export interface ImagebuilderHttpAuthSchemeProvider extends HttpAuthSchemeProvider<ImagebuilderHttpAuthSchemeParameters> {
}
/**
 * @internal
 */
export declare const defaultImagebuilderHttpAuthSchemeProvider: ImagebuilderHttpAuthSchemeProvider;
/**
 * @internal
 */
export interface HttpAuthSchemeInputConfig extends AwsSdkSigV4AuthInputConfig {
    /**
     * experimentalIdentityAndAuth: Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    httpAuthSchemes?: HttpAuthScheme[];
    /**
     * experimentalIdentityAndAuth: Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    httpAuthSchemeProvider?: ImagebuilderHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export interface HttpAuthSchemeResolvedConfig extends AwsSdkSigV4AuthResolvedConfig {
    /**
     * experimentalIdentityAndAuth: Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    readonly httpAuthSchemes: HttpAuthScheme[];
    /**
     * experimentalIdentityAndAuth: Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    readonly httpAuthSchemeProvider: ImagebuilderHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export declare const resolveHttpAuthSchemeConfig: <T>(config: T & HttpAuthSchemeInputConfig & AwsSdkSigV4PreviouslyResolved) => T & HttpAuthSchemeResolvedConfig;
