import { AwsSdkSigV4AuthInputConfig, AwsSdkSigV4AuthResolvedConfig, AwsSdkSigV4PreviouslyResolved } from "@aws-sdk/core";
import { HandlerExecutionContext, HttpAuthScheme, HttpAuthSchemeParameters, HttpAuthSchemeParametersProvider, HttpAuthSchemeProvider } from "@smithy/types";
import { OpenSearchClientResolvedConfig } from "../OpenSearchClient";
/**
 * @internal
 */
export interface OpenSearchHttpAuthSchemeParameters extends HttpAuthSchemeParameters {
    region?: string;
}
/**
 * @internal
 */
export interface OpenSearchHttpAuthSchemeParametersProvider extends HttpAuthSchemeParametersProvider<OpenSearchClientResolvedConfig, HandlerExecutionContext, OpenSearchHttpAuthSchemeParameters, object> {
}
/**
 * @internal
 */
export declare const defaultOpenSearchHttpAuthSchemeParametersProvider: (config: OpenSearchClientResolvedConfig, context: HandlerExecutionContext, input: object) => Promise<OpenSearchHttpAuthSchemeParameters>;
/**
 * @internal
 */
export interface OpenSearchHttpAuthSchemeProvider extends HttpAuthSchemeProvider<OpenSearchHttpAuthSchemeParameters> {
}
/**
 * @internal
 */
export declare const defaultOpenSearchHttpAuthSchemeProvider: OpenSearchHttpAuthSchemeProvider;
/**
 * @internal
 */
export interface HttpAuthSchemeInputConfig extends AwsSdkSigV4AuthInputConfig {
    /**
     * experimentalIdentityAndAuth: Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    httpAuthSchemes?: HttpAuthScheme[];
    /**
     * experimentalIdentityAndAuth: Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    httpAuthSchemeProvider?: OpenSearchHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export interface HttpAuthSchemeResolvedConfig extends AwsSdkSigV4AuthResolvedConfig {
    /**
     * experimentalIdentityAndAuth: Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    readonly httpAuthSchemes: HttpAuthScheme[];
    /**
     * experimentalIdentityAndAuth: Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    readonly httpAuthSchemeProvider: OpenSearchHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export declare const resolveHttpAuthSchemeConfig: <T>(config: T & HttpAuthSchemeInputConfig & AwsSdkSigV4PreviouslyResolved) => T & HttpAuthSchemeResolvedConfig;
