import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { AddDataSourceRequest, AddDataSourceResponse } from "../models/models_0";
import { OpenSearchClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../OpenSearchClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link AddDataSourceCommand}.
 */
export interface AddDataSourceCommandInput extends AddDataSourceRequest {
}
/**
 * @public
 *
 * The output of {@link AddDataSourceCommand}.
 */
export interface AddDataSourceCommandOutput extends AddDataSourceResponse, __MetadataBearer {
}
declare const AddDataSourceCommand_base: {
    new (input: AddDataSourceCommandInput): import("@smithy/smithy-client").CommandImpl<AddDataSourceCommandInput, AddDataSourceCommandOutput, OpenSearchClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: AddDataSourceCommandInput): import("@smithy/smithy-client").CommandImpl<AddDataSourceCommandInput, AddDataSourceCommandOutput, OpenSearchClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Creates a new direct-query data source to the specified domain. For more information, see
 *    <a href="https://docs.aws.amazon.com/opensearch-service/latest/developerguide/direct-query-s3-creating.html">Creating Amazon OpenSearch Service data source integrations with Amazon S3</a>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { OpenSearchClient, AddDataSourceCommand } from "@aws-sdk/client-opensearch"; // ES Modules import
 * // const { OpenSearchClient, AddDataSourceCommand } = require("@aws-sdk/client-opensearch"); // CommonJS import
 * const client = new OpenSearchClient(config);
 * const input = { // AddDataSourceRequest
 *   DomainName: "STRING_VALUE", // required
 *   Name: "STRING_VALUE", // required
 *   DataSourceType: { // DataSourceType Union: only one key present
 *     S3GlueDataCatalog: { // S3GlueDataCatalog
 *       RoleArn: "STRING_VALUE",
 *     },
 *   },
 *   Description: "STRING_VALUE",
 * };
 * const command = new AddDataSourceCommand(input);
 * const response = await client.send(command);
 * // { // AddDataSourceResponse
 * //   Message: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param AddDataSourceCommandInput - {@link AddDataSourceCommandInput}
 * @returns {@link AddDataSourceCommandOutput}
 * @see {@link AddDataSourceCommandInput} for command's `input` shape.
 * @see {@link AddDataSourceCommandOutput} for command's `response` shape.
 * @see {@link OpenSearchClientResolvedConfig | config} for OpenSearchClient's `config` shape.
 *
 * @throws {@link BaseException} (client fault)
 *  <p>An error occurred while processing the request.</p>
 *
 * @throws {@link DependencyFailureException} (client fault)
 *  <p>An exception for when a failure in one of the dependencies results in the service being unable to fetch details about the resource.</p>
 *
 * @throws {@link DisabledOperationException} (client fault)
 *  <p>An error occured because the client wanted to access an unsupported operation.</p>
 *
 * @throws {@link InternalException} (server fault)
 *  <p>Request processing failed because of an unknown error, exception, or internal failure.</p>
 *
 * @throws {@link LimitExceededException} (client fault)
 *  <p>An exception for trying to create more than the allowed number of resources or sub-resources.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>An exception for accessing or deleting a resource that doesn't exist.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>An exception for accessing or deleting a resource that doesn't exist.</p>
 *
 * @throws {@link OpenSearchServiceException}
 * <p>Base exception class for all service exceptions from OpenSearch service.</p>
 *
 * @public
 */
export declare class AddDataSourceCommand extends AddDataSourceCommand_base {
}
