import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import { OpenSearchServiceException as __BaseException } from "./OpenSearchServiceException";
export interface AcceptInboundConnectionRequest {
  ConnectionId: string | undefined;
}
export declare const ConnectionMode: {
  readonly DIRECT: "DIRECT";
  readonly VPC_ENDPOINT: "VPC_ENDPOINT";
};
export type ConnectionMode =
  (typeof ConnectionMode)[keyof typeof ConnectionMode];
export declare const InboundConnectionStatusCode: {
  readonly ACTIVE: "ACTIVE";
  readonly APPROVED: "APPROVED";
  readonly DELETED: "DELETED";
  readonly DELETING: "DELETING";
  readonly PENDING_ACCEPTANCE: "PENDING_ACCEPTANCE";
  readonly PROVISIONING: "PROVISIONING";
  readonly REJECTED: "REJECTED";
  readonly REJECTING: "REJECTING";
};
export type InboundConnectionStatusCode =
  (typeof InboundConnectionStatusCode)[keyof typeof InboundConnectionStatusCode];
export interface InboundConnectionStatus {
  StatusCode?: InboundConnectionStatusCode;
  Message?: string;
}
export interface AWSDomainInformation {
  OwnerId?: string;
  DomainName: string | undefined;
  Region?: string;
}
export interface DomainInformationContainer {
  AWSDomainInformation?: AWSDomainInformation;
}
export interface InboundConnection {
  LocalDomainInfo?: DomainInformationContainer;
  RemoteDomainInfo?: DomainInformationContainer;
  ConnectionId?: string;
  ConnectionStatus?: InboundConnectionStatus;
  ConnectionMode?: ConnectionMode;
}
export interface AcceptInboundConnectionResponse {
  Connection?: InboundConnection;
}
export declare class DisabledOperationException extends __BaseException {
  readonly name: "DisabledOperationException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<DisabledOperationException, __BaseException>
  );
}
export declare class LimitExceededException extends __BaseException {
  readonly name: "LimitExceededException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<LimitExceededException, __BaseException>
  );
}
export declare class ResourceNotFoundException extends __BaseException {
  readonly name: "ResourceNotFoundException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>
  );
}
export declare class AccessDeniedException extends __BaseException {
  readonly name: "AccessDeniedException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<AccessDeniedException, __BaseException>
  );
}
export declare const OptionState: {
  readonly Active: "Active";
  readonly Processing: "Processing";
  readonly RequiresIndexDocuments: "RequiresIndexDocuments";
};
export type OptionState = (typeof OptionState)[keyof typeof OptionState];
export interface OptionStatus {
  CreationDate: Date | undefined;
  UpdateDate: Date | undefined;
  UpdateVersion?: number;
  State: OptionState | undefined;
  PendingDeletion?: boolean;
}
export interface AccessPoliciesStatus {
  Options: string | undefined;
  Status: OptionStatus | undefined;
}
export declare const ActionSeverity: {
  readonly HIGH: "HIGH";
  readonly LOW: "LOW";
  readonly MEDIUM: "MEDIUM";
};
export type ActionSeverity =
  (typeof ActionSeverity)[keyof typeof ActionSeverity];
export declare const ActionStatus: {
  readonly COMPLETED: "COMPLETED";
  readonly ELIGIBLE: "ELIGIBLE";
  readonly FAILED: "FAILED";
  readonly IN_PROGRESS: "IN_PROGRESS";
  readonly NOT_ELIGIBLE: "NOT_ELIGIBLE";
  readonly PENDING_UPDATE: "PENDING_UPDATE";
};
export type ActionStatus = (typeof ActionStatus)[keyof typeof ActionStatus];
export declare const ActionType: {
  readonly JVM_HEAP_SIZE_TUNING: "JVM_HEAP_SIZE_TUNING";
  readonly JVM_YOUNG_GEN_TUNING: "JVM_YOUNG_GEN_TUNING";
  readonly SERVICE_SOFTWARE_UPDATE: "SERVICE_SOFTWARE_UPDATE";
};
export type ActionType = (typeof ActionType)[keyof typeof ActionType];
export interface S3GlueDataCatalog {
  RoleArn?: string;
}
export type DataSourceType =
  | DataSourceType.S3GlueDataCatalogMember
  | DataSourceType.$UnknownMember;
export declare namespace DataSourceType {
  interface S3GlueDataCatalogMember {
    S3GlueDataCatalog: S3GlueDataCatalog;
    $unknown?: never;
  }
  interface $UnknownMember {
    S3GlueDataCatalog?: never;
    $unknown: [string, any];
  }
  interface Visitor<T> {
    S3GlueDataCatalog: (value: S3GlueDataCatalog) => T;
    _: (name: string, value: any) => T;
  }
  const visit: <T>(value: DataSourceType, visitor: Visitor<T>) => T;
}
export interface AddDataSourceRequest {
  DomainName: string | undefined;
  Name: string | undefined;
  DataSourceType: DataSourceType | undefined;
  Description?: string;
}
export interface AddDataSourceResponse {
  Message?: string;
}
export declare class BaseException extends __BaseException {
  readonly name: "BaseException";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<BaseException, __BaseException>);
}
export declare class DependencyFailureException extends __BaseException {
  readonly name: "DependencyFailureException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<DependencyFailureException, __BaseException>
  );
}
export declare class InternalException extends __BaseException {
  readonly name: "InternalException";
  readonly $fault: "server";
  constructor(opts: __ExceptionOptionType<InternalException, __BaseException>);
}
export declare class ValidationException extends __BaseException {
  readonly name: "ValidationException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<ValidationException, __BaseException>
  );
}
export interface AdditionalLimit {
  LimitName?: string;
  LimitValues?: string[];
}
export interface Tag {
  Key: string | undefined;
  Value: string | undefined;
}
export interface AddTagsRequest {
  ARN: string | undefined;
  TagList: Tag[] | undefined;
}
export interface AdvancedOptionsStatus {
  Options: Record<string, string> | undefined;
  Status: OptionStatus | undefined;
}
export interface SAMLIdp {
  MetadataContent: string | undefined;
  EntityId: string | undefined;
}
export interface SAMLOptionsOutput {
  Enabled?: boolean;
  Idp?: SAMLIdp;
  SubjectKey?: string;
  RolesKey?: string;
  SessionTimeoutMinutes?: number;
}
export interface AdvancedSecurityOptions {
  Enabled?: boolean;
  InternalUserDatabaseEnabled?: boolean;
  SAMLOptions?: SAMLOptionsOutput;
  AnonymousAuthDisableDate?: Date;
  AnonymousAuthEnabled?: boolean;
}
export interface MasterUserOptions {
  MasterUserARN?: string;
  MasterUserName?: string;
  MasterUserPassword?: string;
}
export interface SAMLOptionsInput {
  Enabled?: boolean;
  Idp?: SAMLIdp;
  MasterUserName?: string;
  MasterBackendRole?: string;
  SubjectKey?: string;
  RolesKey?: string;
  SessionTimeoutMinutes?: number;
}
export interface AdvancedSecurityOptionsInput {
  Enabled?: boolean;
  InternalUserDatabaseEnabled?: boolean;
  MasterUserOptions?: MasterUserOptions;
  SAMLOptions?: SAMLOptionsInput;
  AnonymousAuthEnabled?: boolean;
}
export interface AdvancedSecurityOptionsStatus {
  Options: AdvancedSecurityOptions | undefined;
  Status: OptionStatus | undefined;
}
export interface AssociatePackageRequest {
  PackageID: string | undefined;
  DomainName: string | undefined;
}
export declare const DomainPackageStatus: {
  readonly ACTIVE: "ACTIVE";
  readonly ASSOCIATING: "ASSOCIATING";
  readonly ASSOCIATION_FAILED: "ASSOCIATION_FAILED";
  readonly DISSOCIATING: "DISSOCIATING";
  readonly DISSOCIATION_FAILED: "DISSOCIATION_FAILED";
};
export type DomainPackageStatus =
  (typeof DomainPackageStatus)[keyof typeof DomainPackageStatus];
export interface ErrorDetails {
  ErrorType?: string;
  ErrorMessage?: string;
}
export declare const PackageType: {
  readonly TXT_DICTIONARY: "TXT-DICTIONARY";
  readonly ZIP_PLUGIN: "ZIP-PLUGIN";
};
export type PackageType = (typeof PackageType)[keyof typeof PackageType];
export interface DomainPackageDetails {
  PackageID?: string;
  PackageName?: string;
  PackageType?: PackageType;
  LastUpdated?: Date;
  DomainName?: string;
  DomainPackageStatus?: DomainPackageStatus;
  PackageVersion?: string;
  ReferencePath?: string;
  ErrorDetails?: ErrorDetails;
}
export interface AssociatePackageResponse {
  DomainPackageDetails?: DomainPackageDetails;
}
export declare class ConflictException extends __BaseException {
  readonly name: "ConflictException";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}
export interface AuthorizeVpcEndpointAccessRequest {
  DomainName: string | undefined;
  Account: string | undefined;
}
export declare const PrincipalType: {
  readonly AWS_ACCOUNT: "AWS_ACCOUNT";
  readonly AWS_SERVICE: "AWS_SERVICE";
};
export type PrincipalType = (typeof PrincipalType)[keyof typeof PrincipalType];
export interface AuthorizedPrincipal {
  PrincipalType?: PrincipalType;
  Principal?: string;
}
export interface AuthorizeVpcEndpointAccessResponse {
  AuthorizedPrincipal: AuthorizedPrincipal | undefined;
}
export interface CancelDomainConfigChangeRequest {
  DomainName: string | undefined;
  DryRun?: boolean;
}
export interface CancelledChangeProperty {
  PropertyName?: string;
  CancelledValue?: string;
  ActiveValue?: string;
}
export interface CancelDomainConfigChangeResponse {
  CancelledChangeIds?: string[];
  CancelledChangeProperties?: CancelledChangeProperty[];
  DryRun?: boolean;
}
export interface CancelServiceSoftwareUpdateRequest {
  DomainName: string | undefined;
}
export declare const DeploymentStatus: {
  readonly COMPLETED: "COMPLETED";
  readonly ELIGIBLE: "ELIGIBLE";
  readonly IN_PROGRESS: "IN_PROGRESS";
  readonly NOT_ELIGIBLE: "NOT_ELIGIBLE";
  readonly PENDING_UPDATE: "PENDING_UPDATE";
};
export type DeploymentStatus =
  (typeof DeploymentStatus)[keyof typeof DeploymentStatus];
export interface ServiceSoftwareOptions {
  CurrentVersion?: string;
  NewVersion?: string;
  UpdateAvailable?: boolean;
  Cancellable?: boolean;
  UpdateStatus?: DeploymentStatus;
  Description?: string;
  AutomatedUpdateDate?: Date;
  OptionalDeployment?: boolean;
}
export interface CancelServiceSoftwareUpdateResponse {
  ServiceSoftwareOptions?: ServiceSoftwareOptions;
}
export declare const AutoTuneDesiredState: {
  readonly DISABLED: "DISABLED";
  readonly ENABLED: "ENABLED";
};
export type AutoTuneDesiredState =
  (typeof AutoTuneDesiredState)[keyof typeof AutoTuneDesiredState];
export declare const TimeUnit: {
  readonly HOURS: "HOURS";
};
export type TimeUnit = (typeof TimeUnit)[keyof typeof TimeUnit];
export interface Duration {
  Value?: number;
  Unit?: TimeUnit;
}
export interface AutoTuneMaintenanceSchedule {
  StartAt?: Date;
  Duration?: Duration;
  CronExpressionForRecurrence?: string;
}
export interface AutoTuneOptionsInput {
  DesiredState?: AutoTuneDesiredState;
  MaintenanceSchedules?: AutoTuneMaintenanceSchedule[];
  UseOffPeakWindow?: boolean;
}
export interface ColdStorageOptions {
  Enabled: boolean | undefined;
}
export declare const OpenSearchPartitionInstanceType: {
  readonly c4_2xlarge_search: "c4.2xlarge.search";
  readonly c4_4xlarge_search: "c4.4xlarge.search";
  readonly c4_8xlarge_search: "c4.8xlarge.search";
  readonly c4_large_search: "c4.large.search";
  readonly c4_xlarge_search: "c4.xlarge.search";
  readonly c5_18xlarge_search: "c5.18xlarge.search";
  readonly c5_2xlarge_search: "c5.2xlarge.search";
  readonly c5_4xlarge_search: "c5.4xlarge.search";
  readonly c5_9xlarge_search: "c5.9xlarge.search";
  readonly c5_large_search: "c5.large.search";
  readonly c5_xlarge_search: "c5.xlarge.search";
  readonly c6g_12xlarge_search: "c6g.12xlarge.search";
  readonly c6g_2xlarge_search: "c6g.2xlarge.search";
  readonly c6g_4xlarge_search: "c6g.4xlarge.search";
  readonly c6g_8xlarge_search: "c6g.8xlarge.search";
  readonly c6g_large_search: "c6g.large.search";
  readonly c6g_xlarge_search: "c6g.xlarge.search";
  readonly d2_2xlarge_search: "d2.2xlarge.search";
  readonly d2_4xlarge_search: "d2.4xlarge.search";
  readonly d2_8xlarge_search: "d2.8xlarge.search";
  readonly d2_xlarge_search: "d2.xlarge.search";
  readonly i2_2xlarge_search: "i2.2xlarge.search";
  readonly i2_xlarge_search: "i2.xlarge.search";
  readonly i3_16xlarge_search: "i3.16xlarge.search";
  readonly i3_2xlarge_search: "i3.2xlarge.search";
  readonly i3_4xlarge_search: "i3.4xlarge.search";
  readonly i3_8xlarge_search: "i3.8xlarge.search";
  readonly i3_large_search: "i3.large.search";
  readonly i3_xlarge_search: "i3.xlarge.search";
  readonly m3_2xlarge_search: "m3.2xlarge.search";
  readonly m3_large_search: "m3.large.search";
  readonly m3_medium_search: "m3.medium.search";
  readonly m3_xlarge_search: "m3.xlarge.search";
  readonly m4_10xlarge_search: "m4.10xlarge.search";
  readonly m4_2xlarge_search: "m4.2xlarge.search";
  readonly m4_4xlarge_search: "m4.4xlarge.search";
  readonly m4_large_search: "m4.large.search";
  readonly m4_xlarge_search: "m4.xlarge.search";
  readonly m5_12xlarge_search: "m5.12xlarge.search";
  readonly m5_24xlarge_search: "m5.24xlarge.search";
  readonly m5_2xlarge_search: "m5.2xlarge.search";
  readonly m5_4xlarge_search: "m5.4xlarge.search";
  readonly m5_large_search: "m5.large.search";
  readonly m5_xlarge_search: "m5.xlarge.search";
  readonly m6g_12xlarge_search: "m6g.12xlarge.search";
  readonly m6g_2xlarge_search: "m6g.2xlarge.search";
  readonly m6g_4xlarge_search: "m6g.4xlarge.search";
  readonly m6g_8xlarge_search: "m6g.8xlarge.search";
  readonly m6g_large_search: "m6g.large.search";
  readonly m6g_xlarge_search: "m6g.xlarge.search";
  readonly or1_12xlarge_search: "or1.12xlarge.search";
  readonly or1_16xlarge_search: "or1.16xlarge.search";
  readonly or1_2xlarge_search: "or1.2xlarge.search";
  readonly or1_4xlarge_search: "or1.4xlarge.search";
  readonly or1_8xlarge_search: "or1.8xlarge.search";
  readonly or1_large_search: "or1.large.search";
  readonly or1_medium_search: "or1.medium.search";
  readonly or1_xlarge_search: "or1.xlarge.search";
  readonly r3_2xlarge_search: "r3.2xlarge.search";
  readonly r3_4xlarge_search: "r3.4xlarge.search";
  readonly r3_8xlarge_search: "r3.8xlarge.search";
  readonly r3_large_search: "r3.large.search";
  readonly r3_xlarge_search: "r3.xlarge.search";
  readonly r4_16xlarge_search: "r4.16xlarge.search";
  readonly r4_2xlarge_search: "r4.2xlarge.search";
  readonly r4_4xlarge_search: "r4.4xlarge.search";
  readonly r4_8xlarge_search: "r4.8xlarge.search";
  readonly r4_large_search: "r4.large.search";
  readonly r4_xlarge_search: "r4.xlarge.search";
  readonly r5_12xlarge_search: "r5.12xlarge.search";
  readonly r5_24xlarge_search: "r5.24xlarge.search";
  readonly r5_2xlarge_search: "r5.2xlarge.search";
  readonly r5_4xlarge_search: "r5.4xlarge.search";
  readonly r5_large_search: "r5.large.search";
  readonly r5_xlarge_search: "r5.xlarge.search";
  readonly r6g_12xlarge_search: "r6g.12xlarge.search";
  readonly r6g_2xlarge_search: "r6g.2xlarge.search";
  readonly r6g_4xlarge_search: "r6g.4xlarge.search";
  readonly r6g_8xlarge_search: "r6g.8xlarge.search";
  readonly r6g_large_search: "r6g.large.search";
  readonly r6g_xlarge_search: "r6g.xlarge.search";
  readonly r6gd_12xlarge_search: "r6gd.12xlarge.search";
  readonly r6gd_16xlarge_search: "r6gd.16xlarge.search";
  readonly r6gd_2xlarge_search: "r6gd.2xlarge.search";
  readonly r6gd_4xlarge_search: "r6gd.4xlarge.search";
  readonly r6gd_8xlarge_search: "r6gd.8xlarge.search";
  readonly r6gd_large_search: "r6gd.large.search";
  readonly r6gd_xlarge_search: "r6gd.xlarge.search";
  readonly t2_medium_search: "t2.medium.search";
  readonly t2_micro_search: "t2.micro.search";
  readonly t2_small_search: "t2.small.search";
  readonly t3_2xlarge_search: "t3.2xlarge.search";
  readonly t3_large_search: "t3.large.search";
  readonly t3_medium_search: "t3.medium.search";
  readonly t3_micro_search: "t3.micro.search";
  readonly t3_nano_search: "t3.nano.search";
  readonly t3_small_search: "t3.small.search";
  readonly t3_xlarge_search: "t3.xlarge.search";
  readonly t4g_medium_search: "t4g.medium.search";
  readonly t4g_small_search: "t4g.small.search";
  readonly ultrawarm1_large_search: "ultrawarm1.large.search";
  readonly ultrawarm1_medium_search: "ultrawarm1.medium.search";
  readonly ultrawarm1_xlarge_search: "ultrawarm1.xlarge.search";
};
export type OpenSearchPartitionInstanceType =
  (typeof OpenSearchPartitionInstanceType)[keyof typeof OpenSearchPartitionInstanceType];
export declare const OpenSearchWarmPartitionInstanceType: {
  readonly ultrawarm1_large_search: "ultrawarm1.large.search";
  readonly ultrawarm1_medium_search: "ultrawarm1.medium.search";
  readonly ultrawarm1_xlarge_search: "ultrawarm1.xlarge.search";
};
export type OpenSearchWarmPartitionInstanceType =
  (typeof OpenSearchWarmPartitionInstanceType)[keyof typeof OpenSearchWarmPartitionInstanceType];
export interface ZoneAwarenessConfig {
  AvailabilityZoneCount?: number;
}
export interface ClusterConfig {
  InstanceType?: OpenSearchPartitionInstanceType;
  InstanceCount?: number;
  DedicatedMasterEnabled?: boolean;
  ZoneAwarenessEnabled?: boolean;
  ZoneAwarenessConfig?: ZoneAwarenessConfig;
  DedicatedMasterType?: OpenSearchPartitionInstanceType;
  DedicatedMasterCount?: number;
  WarmEnabled?: boolean;
  WarmType?: OpenSearchWarmPartitionInstanceType;
  WarmCount?: number;
  ColdStorageOptions?: ColdStorageOptions;
  MultiAZWithStandbyEnabled?: boolean;
}
export interface CognitoOptions {
  Enabled?: boolean;
  UserPoolId?: string;
  IdentityPoolId?: string;
  RoleArn?: string;
}
export declare const TLSSecurityPolicy: {
  readonly POLICY_MIN_TLS_1_0_2019_07: "Policy-Min-TLS-1-0-2019-07";
  readonly POLICY_MIN_TLS_1_2_2019_07: "Policy-Min-TLS-1-2-2019-07";
  readonly POLICY_MIN_TLS_1_2_PFS_2023_10: "Policy-Min-TLS-1-2-PFS-2023-10";
};
export type TLSSecurityPolicy =
  (typeof TLSSecurityPolicy)[keyof typeof TLSSecurityPolicy];
export interface DomainEndpointOptions {
  EnforceHTTPS?: boolean;
  TLSSecurityPolicy?: TLSSecurityPolicy;
  CustomEndpointEnabled?: boolean;
  CustomEndpoint?: string;
  CustomEndpointCertificateArn?: string;
}
export declare const VolumeType: {
  readonly gp2: "gp2";
  readonly gp3: "gp3";
  readonly io1: "io1";
  readonly standard: "standard";
};
export type VolumeType = (typeof VolumeType)[keyof typeof VolumeType];
export interface EBSOptions {
  EBSEnabled?: boolean;
  VolumeType?: VolumeType;
  VolumeSize?: number;
  Iops?: number;
  Throughput?: number;
}
export interface EncryptionAtRestOptions {
  Enabled?: boolean;
  KmsKeyId?: string;
}
export declare const IPAddressType: {
  readonly DUALSTACK: "dualstack";
  readonly IPV4: "ipv4";
};
export type IPAddressType = (typeof IPAddressType)[keyof typeof IPAddressType];
export declare const LogType: {
  readonly AUDIT_LOGS: "AUDIT_LOGS";
  readonly ES_APPLICATION_LOGS: "ES_APPLICATION_LOGS";
  readonly INDEX_SLOW_LOGS: "INDEX_SLOW_LOGS";
  readonly SEARCH_SLOW_LOGS: "SEARCH_SLOW_LOGS";
};
export type LogType = (typeof LogType)[keyof typeof LogType];
export interface LogPublishingOption {
  CloudWatchLogsLogGroupArn?: string;
  Enabled?: boolean;
}
export interface NodeToNodeEncryptionOptions {
  Enabled?: boolean;
}
export interface WindowStartTime {
  Hours: number | undefined;
  Minutes: number | undefined;
}
export interface OffPeakWindow {
  WindowStartTime?: WindowStartTime;
}
export interface OffPeakWindowOptions {
  Enabled?: boolean;
  OffPeakWindow?: OffPeakWindow;
}
export interface SnapshotOptions {
  AutomatedSnapshotStartHour?: number;
}
export interface SoftwareUpdateOptions {
  AutoSoftwareUpdateEnabled?: boolean;
}
export interface VPCOptions {
  SubnetIds?: string[];
  SecurityGroupIds?: string[];
}
export interface CreateDomainRequest {
  DomainName: string | undefined;
  EngineVersion?: string;
  ClusterConfig?: ClusterConfig;
  EBSOptions?: EBSOptions;
  AccessPolicies?: string;
  IPAddressType?: IPAddressType;
  SnapshotOptions?: SnapshotOptions;
  VPCOptions?: VPCOptions;
  CognitoOptions?: CognitoOptions;
  EncryptionAtRestOptions?: EncryptionAtRestOptions;
  NodeToNodeEncryptionOptions?: NodeToNodeEncryptionOptions;
  AdvancedOptions?: Record<string, string>;
  LogPublishingOptions?: Partial<Record<LogType, LogPublishingOption>>;
  DomainEndpointOptions?: DomainEndpointOptions;
  AdvancedSecurityOptions?: AdvancedSecurityOptionsInput;
  TagList?: Tag[];
  AutoTuneOptions?: AutoTuneOptionsInput;
  OffPeakWindowOptions?: OffPeakWindowOptions;
  SoftwareUpdateOptions?: SoftwareUpdateOptions;
}
export declare const AutoTuneState: {
  readonly DISABLED: "DISABLED";
  readonly DISABLED_AND_ROLLBACK_COMPLETE: "DISABLED_AND_ROLLBACK_COMPLETE";
  readonly DISABLED_AND_ROLLBACK_ERROR: "DISABLED_AND_ROLLBACK_ERROR";
  readonly DISABLED_AND_ROLLBACK_IN_PROGRESS: "DISABLED_AND_ROLLBACK_IN_PROGRESS";
  readonly DISABLED_AND_ROLLBACK_SCHEDULED: "DISABLED_AND_ROLLBACK_SCHEDULED";
  readonly DISABLE_IN_PROGRESS: "DISABLE_IN_PROGRESS";
  readonly ENABLED: "ENABLED";
  readonly ENABLE_IN_PROGRESS: "ENABLE_IN_PROGRESS";
  readonly ERROR: "ERROR";
};
export type AutoTuneState = (typeof AutoTuneState)[keyof typeof AutoTuneState];
export interface AutoTuneOptionsOutput {
  State?: AutoTuneState;
  ErrorMessage?: string;
  UseOffPeakWindow?: boolean;
}
export declare const ConfigChangeStatus: {
  readonly APPLYING_CHANGES: "ApplyingChanges";
  readonly CANCELLED: "Cancelled";
  readonly COMPLETED: "Completed";
  readonly INITIALIZING: "Initializing";
  readonly PENDING: "Pending";
  readonly PENDING_USER_INPUT: "PendingUserInput";
  readonly VALIDATING: "Validating";
  readonly VALIDATION_FAILED: "ValidationFailed";
};
export type ConfigChangeStatus =
  (typeof ConfigChangeStatus)[keyof typeof ConfigChangeStatus];
export declare const InitiatedBy: {
  readonly CUSTOMER: "CUSTOMER";
  readonly SERVICE: "SERVICE";
};
export type InitiatedBy = (typeof InitiatedBy)[keyof typeof InitiatedBy];
export interface ChangeProgressDetails {
  ChangeId?: string;
  Message?: string;
  ConfigChangeStatus?: ConfigChangeStatus;
  InitiatedBy?: InitiatedBy;
  StartTime?: Date;
  LastUpdatedTime?: Date;
}
export declare const DomainProcessingStatusType: {
  readonly ACTIVE: "Active";
  readonly CREATING: "Creating";
  readonly DELETING: "Deleting";
  readonly ISOLATED: "Isolated";
  readonly MODIFYING: "Modifying";
  readonly UPDATING: "UpdatingServiceSoftware";
  readonly UPGRADING: "UpgradingEngineVersion";
};
export type DomainProcessingStatusType =
  (typeof DomainProcessingStatusType)[keyof typeof DomainProcessingStatusType];
export declare const PropertyValueType: {
  readonly PLAIN_TEXT: "PLAIN_TEXT";
  readonly STRINGIFIED_JSON: "STRINGIFIED_JSON";
};
export type PropertyValueType =
  (typeof PropertyValueType)[keyof typeof PropertyValueType];
export interface ModifyingProperties {
  Name?: string;
  ActiveValue?: string;
  PendingValue?: string;
  ValueType?: PropertyValueType;
}
export interface VPCDerivedInfo {
  VPCId?: string;
  SubnetIds?: string[];
  AvailabilityZones?: string[];
  SecurityGroupIds?: string[];
}
export interface DomainStatus {
  DomainId: string | undefined;
  DomainName: string | undefined;
  ARN: string | undefined;
  Created?: boolean;
  Deleted?: boolean;
  Endpoint?: string;
  EndpointV2?: string;
  Endpoints?: Record<string, string>;
  DomainEndpointV2HostedZoneId?: string;
  Processing?: boolean;
  UpgradeProcessing?: boolean;
  EngineVersion?: string;
  ClusterConfig: ClusterConfig | undefined;
  EBSOptions?: EBSOptions;
  AccessPolicies?: string;
  IPAddressType?: IPAddressType;
  SnapshotOptions?: SnapshotOptions;
  VPCOptions?: VPCDerivedInfo;
  CognitoOptions?: CognitoOptions;
  EncryptionAtRestOptions?: EncryptionAtRestOptions;
  NodeToNodeEncryptionOptions?: NodeToNodeEncryptionOptions;
  AdvancedOptions?: Record<string, string>;
  LogPublishingOptions?: Partial<Record<LogType, LogPublishingOption>>;
  ServiceSoftwareOptions?: ServiceSoftwareOptions;
  DomainEndpointOptions?: DomainEndpointOptions;
  AdvancedSecurityOptions?: AdvancedSecurityOptions;
  AutoTuneOptions?: AutoTuneOptionsOutput;
  ChangeProgressDetails?: ChangeProgressDetails;
  OffPeakWindowOptions?: OffPeakWindowOptions;
  SoftwareUpdateOptions?: SoftwareUpdateOptions;
  DomainProcessingStatus?: DomainProcessingStatusType;
  ModifyingProperties?: ModifyingProperties[];
}
export interface CreateDomainResponse {
  DomainStatus?: DomainStatus;
}
export declare class InvalidTypeException extends __BaseException {
  readonly name: "InvalidTypeException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<InvalidTypeException, __BaseException>
  );
}
export declare class ResourceAlreadyExistsException extends __BaseException {
  readonly name: "ResourceAlreadyExistsException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<ResourceAlreadyExistsException, __BaseException>
  );
}
export declare const SkipUnavailableStatus: {
  readonly DISABLED: "DISABLED";
  readonly ENABLED: "ENABLED";
};
export type SkipUnavailableStatus =
  (typeof SkipUnavailableStatus)[keyof typeof SkipUnavailableStatus];
export interface CrossClusterSearchConnectionProperties {
  SkipUnavailable?: SkipUnavailableStatus;
}
export interface ConnectionProperties {
  Endpoint?: string;
  CrossClusterSearch?: CrossClusterSearchConnectionProperties;
}
export interface CreateOutboundConnectionRequest {
  LocalDomainInfo: DomainInformationContainer | undefined;
  RemoteDomainInfo: DomainInformationContainer | undefined;
  ConnectionAlias: string | undefined;
  ConnectionMode?: ConnectionMode;
  ConnectionProperties?: ConnectionProperties;
}
export declare const OutboundConnectionStatusCode: {
  readonly ACTIVE: "ACTIVE";
  readonly APPROVED: "APPROVED";
  readonly DELETED: "DELETED";
  readonly DELETING: "DELETING";
  readonly PENDING_ACCEPTANCE: "PENDING_ACCEPTANCE";
  readonly PROVISIONING: "PROVISIONING";
  readonly REJECTED: "REJECTED";
  readonly REJECTING: "REJECTING";
  readonly VALIDATING: "VALIDATING";
  readonly VALIDATION_FAILED: "VALIDATION_FAILED";
};
export type OutboundConnectionStatusCode =
  (typeof OutboundConnectionStatusCode)[keyof typeof OutboundConnectionStatusCode];
export interface OutboundConnectionStatus {
  StatusCode?: OutboundConnectionStatusCode;
  Message?: string;
}
export interface CreateOutboundConnectionResponse {
  LocalDomainInfo?: DomainInformationContainer;
  RemoteDomainInfo?: DomainInformationContainer;
  ConnectionAlias?: string;
  ConnectionStatus?: OutboundConnectionStatus;
  ConnectionId?: string;
  ConnectionMode?: ConnectionMode;
  ConnectionProperties?: ConnectionProperties;
}
export interface PackageSource {
  S3BucketName?: string;
  S3Key?: string;
}
export interface CreatePackageRequest {
  PackageName: string | undefined;
  PackageType: PackageType | undefined;
  PackageDescription?: string;
  PackageSource: PackageSource | undefined;
}
export interface PluginProperties {
  Name?: string;
  Description?: string;
  Version?: string;
  ClassName?: string;
  UncompressedSizeInBytes?: number;
}
export declare const PackageStatus: {
  readonly AVAILABLE: "AVAILABLE";
  readonly COPYING: "COPYING";
  readonly COPY_FAILED: "COPY_FAILED";
  readonly DELETED: "DELETED";
  readonly DELETE_FAILED: "DELETE_FAILED";
  readonly DELETING: "DELETING";
  readonly VALIDATING: "VALIDATING";
  readonly VALIDATION_FAILED: "VALIDATION_FAILED";
};
export type PackageStatus = (typeof PackageStatus)[keyof typeof PackageStatus];
export interface PackageDetails {
  PackageID?: string;
  PackageName?: string;
  PackageType?: PackageType;
  PackageDescription?: string;
  PackageStatus?: PackageStatus;
  CreatedAt?: Date;
  LastUpdatedAt?: Date;
  AvailablePackageVersion?: string;
  ErrorDetails?: ErrorDetails;
  EngineVersion?: string;
  AvailablePluginProperties?: PluginProperties;
}
export interface CreatePackageResponse {
  PackageDetails?: PackageDetails;
}
export interface CreateVpcEndpointRequest {
  DomainArn: string | undefined;
  VpcOptions: VPCOptions | undefined;
  ClientToken?: string;
}
export declare const VpcEndpointStatus: {
  readonly ACTIVE: "ACTIVE";
  readonly CREATE_FAILED: "CREATE_FAILED";
  readonly CREATING: "CREATING";
  readonly DELETE_FAILED: "DELETE_FAILED";
  readonly DELETING: "DELETING";
  readonly UPDATE_FAILED: "UPDATE_FAILED";
  readonly UPDATING: "UPDATING";
};
export type VpcEndpointStatus =
  (typeof VpcEndpointStatus)[keyof typeof VpcEndpointStatus];
export interface VpcEndpoint {
  VpcEndpointId?: string;
  VpcEndpointOwner?: string;
  DomainArn?: string;
  VpcOptions?: VPCDerivedInfo;
  Status?: VpcEndpointStatus;
  Endpoint?: string;
}
export interface CreateVpcEndpointResponse {
  VpcEndpoint: VpcEndpoint | undefined;
}
export interface DeleteDataSourceRequest {
  DomainName: string | undefined;
  Name: string | undefined;
}
export interface DeleteDataSourceResponse {
  Message?: string;
}
export interface DeleteDomainRequest {
  DomainName: string | undefined;
}
export interface DeleteDomainResponse {
  DomainStatus?: DomainStatus;
}
export interface DeleteInboundConnectionRequest {
  ConnectionId: string | undefined;
}
export interface DeleteInboundConnectionResponse {
  Connection?: InboundConnection;
}
export interface DeleteOutboundConnectionRequest {
  ConnectionId: string | undefined;
}
export interface OutboundConnection {
  LocalDomainInfo?: DomainInformationContainer;
  RemoteDomainInfo?: DomainInformationContainer;
  ConnectionId?: string;
  ConnectionAlias?: string;
  ConnectionStatus?: OutboundConnectionStatus;
  ConnectionMode?: ConnectionMode;
  ConnectionProperties?: ConnectionProperties;
}
export interface DeleteOutboundConnectionResponse {
  Connection?: OutboundConnection;
}
export interface DeletePackageRequest {
  PackageID: string | undefined;
}
export interface DeletePackageResponse {
  PackageDetails?: PackageDetails;
}
export interface DeleteVpcEndpointRequest {
  VpcEndpointId: string | undefined;
}
export interface VpcEndpointSummary {
  VpcEndpointId?: string;
  VpcEndpointOwner?: string;
  DomainArn?: string;
  Status?: VpcEndpointStatus;
}
export interface DeleteVpcEndpointResponse {
  VpcEndpointSummary: VpcEndpointSummary | undefined;
}
export interface DescribeDomainRequest {
  DomainName: string | undefined;
}
export interface DescribeDomainResponse {
  DomainStatus: DomainStatus | undefined;
}
export interface DescribeDomainAutoTunesRequest {
  DomainName: string | undefined;
  MaxResults?: number;
  NextToken?: string;
}
export declare const ScheduledAutoTuneActionType: {
  readonly JVM_HEAP_SIZE_TUNING: "JVM_HEAP_SIZE_TUNING";
  readonly JVM_YOUNG_GEN_TUNING: "JVM_YOUNG_GEN_TUNING";
};
export type ScheduledAutoTuneActionType =
  (typeof ScheduledAutoTuneActionType)[keyof typeof ScheduledAutoTuneActionType];
export declare const ScheduledAutoTuneSeverityType: {
  readonly HIGH: "HIGH";
  readonly LOW: "LOW";
  readonly MEDIUM: "MEDIUM";
};
export type ScheduledAutoTuneSeverityType =
  (typeof ScheduledAutoTuneSeverityType)[keyof typeof ScheduledAutoTuneSeverityType];
export interface ScheduledAutoTuneDetails {
  Date?: Date;
  ActionType?: ScheduledAutoTuneActionType;
  Action?: string;
  Severity?: ScheduledAutoTuneSeverityType;
}
export interface AutoTuneDetails {
  ScheduledAutoTuneDetails?: ScheduledAutoTuneDetails;
}
export declare const AutoTuneType: {
  readonly SCHEDULED_ACTION: "SCHEDULED_ACTION";
};
export type AutoTuneType = (typeof AutoTuneType)[keyof typeof AutoTuneType];
export interface AutoTune {
  AutoTuneType?: AutoTuneType;
  AutoTuneDetails?: AutoTuneDetails;
}
export interface DescribeDomainAutoTunesResponse {
  AutoTunes?: AutoTune[];
  NextToken?: string;
}
export interface DescribeDomainChangeProgressRequest {
  DomainName: string | undefined;
  ChangeId?: string;
}
export interface ChangeProgressStage {
  Name?: string;
  Status?: string;
  Description?: string;
  LastUpdated?: Date;
}
export declare const OverallChangeStatus: {
  readonly COMPLETED: "COMPLETED";
  readonly FAILED: "FAILED";
  readonly PENDING: "PENDING";
  readonly PROCESSING: "PROCESSING";
};
export type OverallChangeStatus =
  (typeof OverallChangeStatus)[keyof typeof OverallChangeStatus];
export interface ChangeProgressStatusDetails {
  ChangeId?: string;
  StartTime?: Date;
  Status?: OverallChangeStatus;
  PendingProperties?: string[];
  CompletedProperties?: string[];
  TotalNumberOfStages?: number;
  ChangeProgressStages?: ChangeProgressStage[];
  LastUpdatedTime?: Date;
  ConfigChangeStatus?: ConfigChangeStatus;
  InitiatedBy?: InitiatedBy;
}
export interface DescribeDomainChangeProgressResponse {
  ChangeProgressStatus?: ChangeProgressStatusDetails;
}
export interface DescribeDomainConfigRequest {
  DomainName: string | undefined;
}
export declare const RollbackOnDisable: {
  readonly DEFAULT_ROLLBACK: "DEFAULT_ROLLBACK";
  readonly NO_ROLLBACK: "NO_ROLLBACK";
};
export type RollbackOnDisable =
  (typeof RollbackOnDisable)[keyof typeof RollbackOnDisable];
export interface AutoTuneOptions {
  DesiredState?: AutoTuneDesiredState;
  RollbackOnDisable?: RollbackOnDisable;
  MaintenanceSchedules?: AutoTuneMaintenanceSchedule[];
  UseOffPeakWindow?: boolean;
}
export interface AutoTuneStatus {
  CreationDate: Date | undefined;
  UpdateDate: Date | undefined;
  UpdateVersion?: number;
  State: AutoTuneState | undefined;
  ErrorMessage?: string;
  PendingDeletion?: boolean;
}
export interface AutoTuneOptionsStatus {
  Options?: AutoTuneOptions;
  Status?: AutoTuneStatus;
}
export interface ClusterConfigStatus {
  Options: ClusterConfig | undefined;
  Status: OptionStatus | undefined;
}
export interface CognitoOptionsStatus {
  Options: CognitoOptions | undefined;
  Status: OptionStatus | undefined;
}
export interface DomainEndpointOptionsStatus {
  Options: DomainEndpointOptions | undefined;
  Status: OptionStatus | undefined;
}
export interface EBSOptionsStatus {
  Options: EBSOptions | undefined;
  Status: OptionStatus | undefined;
}
export interface EncryptionAtRestOptionsStatus {
  Options: EncryptionAtRestOptions | undefined;
  Status: OptionStatus | undefined;
}
export interface VersionStatus {
  Options: string | undefined;
  Status: OptionStatus | undefined;
}
export interface IPAddressTypeStatus {
  Options: IPAddressType | undefined;
  Status: OptionStatus | undefined;
}
export interface LogPublishingOptionsStatus {
  Options?: Partial<Record<LogType, LogPublishingOption>>;
  Status?: OptionStatus;
}
export interface NodeToNodeEncryptionOptionsStatus {
  Options: NodeToNodeEncryptionOptions | undefined;
  Status: OptionStatus | undefined;
}
export interface OffPeakWindowOptionsStatus {
  Options?: OffPeakWindowOptions;
  Status?: OptionStatus;
}
export interface SnapshotOptionsStatus {
  Options: SnapshotOptions | undefined;
  Status: OptionStatus | undefined;
}
export interface SoftwareUpdateOptionsStatus {
  Options?: SoftwareUpdateOptions;
  Status?: OptionStatus;
}
export interface VPCDerivedInfoStatus {
  Options: VPCDerivedInfo | undefined;
  Status: OptionStatus | undefined;
}
export interface DomainConfig {
  EngineVersion?: VersionStatus;
  ClusterConfig?: ClusterConfigStatus;
  EBSOptions?: EBSOptionsStatus;
  AccessPolicies?: AccessPoliciesStatus;
  IPAddressType?: IPAddressTypeStatus;
  SnapshotOptions?: SnapshotOptionsStatus;
  VPCOptions?: VPCDerivedInfoStatus;
  CognitoOptions?: CognitoOptionsStatus;
  EncryptionAtRestOptions?: EncryptionAtRestOptionsStatus;
  NodeToNodeEncryptionOptions?: NodeToNodeEncryptionOptionsStatus;
  AdvancedOptions?: AdvancedOptionsStatus;
  LogPublishingOptions?: LogPublishingOptionsStatus;
  DomainEndpointOptions?: DomainEndpointOptionsStatus;
  AdvancedSecurityOptions?: AdvancedSecurityOptionsStatus;
  AutoTuneOptions?: AutoTuneOptionsStatus;
  ChangeProgressDetails?: ChangeProgressDetails;
  OffPeakWindowOptions?: OffPeakWindowOptionsStatus;
  SoftwareUpdateOptions?: SoftwareUpdateOptionsStatus;
  ModifyingProperties?: ModifyingProperties[];
}
export interface DescribeDomainConfigResponse {
  DomainConfig: DomainConfig | undefined;
}
export interface DescribeDomainHealthRequest {
  DomainName: string | undefined;
}
export declare const DomainHealth: {
  readonly Green: "Green";
  readonly NotAvailable: "NotAvailable";
  readonly Red: "Red";
  readonly Yellow: "Yellow";
};
export type DomainHealth = (typeof DomainHealth)[keyof typeof DomainHealth];
export declare const DomainState: {
  readonly Active: "Active";
  readonly NotAvailable: "NotAvailable";
  readonly Processing: "Processing";
};
export type DomainState = (typeof DomainState)[keyof typeof DomainState];
export declare const ZoneStatus: {
  readonly Active: "Active";
  readonly NotAvailable: "NotAvailable";
  readonly StandBy: "StandBy";
};
export type ZoneStatus = (typeof ZoneStatus)[keyof typeof ZoneStatus];
export interface AvailabilityZoneInfo {
  AvailabilityZoneName?: string;
  ZoneStatus?: ZoneStatus;
  ConfiguredDataNodeCount?: string;
  AvailableDataNodeCount?: string;
  TotalShards?: string;
  TotalUnAssignedShards?: string;
}
export interface EnvironmentInfo {
  AvailabilityZoneInformation?: AvailabilityZoneInfo[];
}
export declare const MasterNodeStatus: {
  readonly Available: "Available";
  readonly UnAvailable: "UnAvailable";
};
export type MasterNodeStatus =
  (typeof MasterNodeStatus)[keyof typeof MasterNodeStatus];
export interface DescribeDomainHealthResponse {
  DomainState?: DomainState;
  AvailabilityZoneCount?: string;
  ActiveAvailabilityZoneCount?: string;
  StandByAvailabilityZoneCount?: string;
  DataNodeCount?: string;
  DedicatedMaster?: boolean;
  MasterEligibleNodeCount?: string;
  WarmNodeCount?: string;
  MasterNode?: MasterNodeStatus;
  ClusterHealth?: DomainHealth;
  TotalShards?: string;
  TotalUnAssignedShards?: string;
  EnvironmentInformation?: EnvironmentInfo[];
}
export interface DescribeDomainNodesRequest {
  DomainName: string | undefined;
}
export declare const NodeStatus: {
  readonly Active: "Active";
  readonly NotAvailable: "NotAvailable";
  readonly StandBy: "StandBy";
};
export type NodeStatus = (typeof NodeStatus)[keyof typeof NodeStatus];
export declare const NodeType: {
  readonly Data: "Data";
  readonly Master: "Master";
  readonly Ultrawarm: "Ultrawarm";
};
export type NodeType = (typeof NodeType)[keyof typeof NodeType];
export interface DomainNodesStatus {
  NodeId?: string;
  NodeType?: NodeType;
  AvailabilityZone?: string;
  InstanceType?: OpenSearchPartitionInstanceType;
  NodeStatus?: NodeStatus;
  StorageType?: string;
  StorageVolumeType?: VolumeType;
  StorageSize?: string;
}
export interface DescribeDomainNodesResponse {
  DomainNodesStatusList?: DomainNodesStatus[];
}
export interface DescribeDomainsRequest {
  DomainNames: string[] | undefined;
}
export interface DescribeDomainsResponse {
  DomainStatusList: DomainStatus[] | undefined;
}
export interface DescribeDryRunProgressRequest {
  DomainName: string | undefined;
  DryRunId?: string;
  LoadDryRunConfig?: boolean;
}
export interface ValidationFailure {
  Code?: string;
  Message?: string;
}
export interface DryRunProgressStatus {
  DryRunId: string | undefined;
  DryRunStatus: string | undefined;
  CreationDate: string | undefined;
  UpdateDate: string | undefined;
  ValidationFailures?: ValidationFailure[];
}
export interface DryRunResults {
  DeploymentType?: string;
  Message?: string;
}
export interface DescribeDryRunProgressResponse {
  DryRunProgressStatus?: DryRunProgressStatus;
  DryRunConfig?: DomainStatus;
  DryRunResults?: DryRunResults;
}
export interface Filter {
  Name?: string;
  Values?: string[];
}
export interface DescribeInboundConnectionsRequest {
  Filters?: Filter[];
  MaxResults?: number;
  NextToken?: string;
}
export interface DescribeInboundConnectionsResponse {
  Connections?: InboundConnection[];
  NextToken?: string;
}
export declare class InvalidPaginationTokenException extends __BaseException {
  readonly name: "InvalidPaginationTokenException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      InvalidPaginationTokenException,
      __BaseException
    >
  );
}
export interface DescribeInstanceTypeLimitsRequest {
  DomainName?: string;
  InstanceType: OpenSearchPartitionInstanceType | undefined;
  EngineVersion: string | undefined;
}
export interface InstanceCountLimits {
  MinimumInstanceCount?: number;
  MaximumInstanceCount?: number;
}
export interface InstanceLimits {
  InstanceCountLimits?: InstanceCountLimits;
}
export interface StorageTypeLimit {
  LimitName?: string;
  LimitValues?: string[];
}
export interface StorageType {
  StorageTypeName?: string;
  StorageSubTypeName?: string;
  StorageTypeLimits?: StorageTypeLimit[];
}
export interface Limits {
  StorageTypes?: StorageType[];
  InstanceLimits?: InstanceLimits;
  AdditionalLimits?: AdditionalLimit[];
}
export interface DescribeInstanceTypeLimitsResponse {
  LimitsByRole?: Record<string, Limits>;
}
export interface DescribeOutboundConnectionsRequest {
  Filters?: Filter[];
  MaxResults?: number;
  NextToken?: string;
}
export interface DescribeOutboundConnectionsResponse {
  Connections?: OutboundConnection[];
  NextToken?: string;
}
export declare const DescribePackagesFilterName: {
  readonly EngineVersion: "EngineVersion";
  readonly PackageID: "PackageID";
  readonly PackageName: "PackageName";
  readonly PackageStatus: "PackageStatus";
  readonly PackageType: "PackageType";
};
export type DescribePackagesFilterName =
  (typeof DescribePackagesFilterName)[keyof typeof DescribePackagesFilterName];
export interface DescribePackagesFilter {
  Name?: DescribePackagesFilterName;
  Value?: string[];
}
export interface DescribePackagesRequest {
  Filters?: DescribePackagesFilter[];
  MaxResults?: number;
  NextToken?: string;
}
export interface DescribePackagesResponse {
  PackageDetailsList?: PackageDetails[];
  NextToken?: string;
}
export interface DescribeReservedInstanceOfferingsRequest {
  ReservedInstanceOfferingId?: string;
  MaxResults?: number;
  NextToken?: string;
}
export declare const ReservedInstancePaymentOption: {
  readonly ALL_UPFRONT: "ALL_UPFRONT";
  readonly NO_UPFRONT: "NO_UPFRONT";
  readonly PARTIAL_UPFRONT: "PARTIAL_UPFRONT";
};
export type ReservedInstancePaymentOption =
  (typeof ReservedInstancePaymentOption)[keyof typeof ReservedInstancePaymentOption];
export interface RecurringCharge {
  RecurringChargeAmount?: number;
  RecurringChargeFrequency?: string;
}
export interface ReservedInstanceOffering {
  ReservedInstanceOfferingId?: string;
  InstanceType?: OpenSearchPartitionInstanceType;
  Duration?: number;
  FixedPrice?: number;
  UsagePrice?: number;
  CurrencyCode?: string;
  PaymentOption?: ReservedInstancePaymentOption;
  RecurringCharges?: RecurringCharge[];
}
export interface DescribeReservedInstanceOfferingsResponse {
  NextToken?: string;
  ReservedInstanceOfferings?: ReservedInstanceOffering[];
}
export interface DescribeReservedInstancesRequest {
  ReservedInstanceId?: string;
  MaxResults?: number;
  NextToken?: string;
}
export interface ReservedInstance {
  ReservationName?: string;
  ReservedInstanceId?: string;
  BillingSubscriptionId?: number;
  ReservedInstanceOfferingId?: string;
  InstanceType?: OpenSearchPartitionInstanceType;
  StartTime?: Date;
  Duration?: number;
  FixedPrice?: number;
  UsagePrice?: number;
  CurrencyCode?: string;
  InstanceCount?: number;
  State?: string;
  PaymentOption?: ReservedInstancePaymentOption;
  RecurringCharges?: RecurringCharge[];
}
export interface DescribeReservedInstancesResponse {
  NextToken?: string;
  ReservedInstances?: ReservedInstance[];
}
export interface DescribeVpcEndpointsRequest {
  VpcEndpointIds: string[] | undefined;
}
export declare const VpcEndpointErrorCode: {
  readonly ENDPOINT_NOT_FOUND: "ENDPOINT_NOT_FOUND";
  readonly SERVER_ERROR: "SERVER_ERROR";
};
export type VpcEndpointErrorCode =
  (typeof VpcEndpointErrorCode)[keyof typeof VpcEndpointErrorCode];
export interface VpcEndpointError {
  VpcEndpointId?: string;
  ErrorCode?: VpcEndpointErrorCode;
  ErrorMessage?: string;
}
export interface DescribeVpcEndpointsResponse {
  VpcEndpoints: VpcEndpoint[] | undefined;
  VpcEndpointErrors: VpcEndpointError[] | undefined;
}
export interface DissociatePackageRequest {
  PackageID: string | undefined;
  DomainName: string | undefined;
}
export interface DissociatePackageResponse {
  DomainPackageDetails?: DomainPackageDetails;
}
export interface GetCompatibleVersionsRequest {
  DomainName?: string;
}
export interface CompatibleVersionsMap {
  SourceVersion?: string;
  TargetVersions?: string[];
}
export interface GetCompatibleVersionsResponse {
  CompatibleVersions?: CompatibleVersionsMap[];
}
export interface GetDataSourceRequest {
  DomainName: string | undefined;
  Name: string | undefined;
}
export declare const DataSourceStatus: {
  readonly ACTIVE: "ACTIVE";
  readonly DISABLED: "DISABLED";
};
export type DataSourceStatus =
  (typeof DataSourceStatus)[keyof typeof DataSourceStatus];
export interface GetDataSourceResponse {
  DataSourceType?: DataSourceType;
  Name?: string;
  Description?: string;
  Status?: DataSourceStatus;
}
export interface GetDomainMaintenanceStatusRequest {
  DomainName: string | undefined;
  MaintenanceId: string | undefined;
}
export declare const MaintenanceType: {
  readonly REBOOT_NODE: "REBOOT_NODE";
  readonly RESTART_DASHBOARD: "RESTART_DASHBOARD";
  readonly RESTART_SEARCH_PROCESS: "RESTART_SEARCH_PROCESS";
};
export type MaintenanceType =
  (typeof MaintenanceType)[keyof typeof MaintenanceType];
export declare const MaintenanceStatus: {
  readonly COMPLETED: "COMPLETED";
  readonly FAILED: "FAILED";
  readonly IN_PROGRESS: "IN_PROGRESS";
  readonly PENDING: "PENDING";
  readonly TIMED_OUT: "TIMED_OUT";
};
export type MaintenanceStatus =
  (typeof MaintenanceStatus)[keyof typeof MaintenanceStatus];
export interface GetDomainMaintenanceStatusResponse {
  Status?: MaintenanceStatus;
  StatusMessage?: string;
  NodeId?: string;
  Action?: MaintenanceType;
  CreatedAt?: Date;
  UpdatedAt?: Date;
}
export interface GetPackageVersionHistoryRequest {
  PackageID: string | undefined;
  MaxResults?: number;
  NextToken?: string;
}
export interface PackageVersionHistory {
  PackageVersion?: string;
  CommitMessage?: string;
  CreatedAt?: Date;
  PluginProperties?: PluginProperties;
}
export interface GetPackageVersionHistoryResponse {
  PackageID?: string;
  PackageVersionHistoryList?: PackageVersionHistory[];
  NextToken?: string;
}
export interface GetUpgradeHistoryRequest {
  DomainName: string | undefined;
  MaxResults?: number;
  NextToken?: string;
}
export declare const UpgradeStep: {
  readonly PRE_UPGRADE_CHECK: "PRE_UPGRADE_CHECK";
  readonly SNAPSHOT: "SNAPSHOT";
  readonly UPGRADE: "UPGRADE";
};
export type UpgradeStep = (typeof UpgradeStep)[keyof typeof UpgradeStep];
export declare const UpgradeStatus: {
  readonly FAILED: "FAILED";
  readonly IN_PROGRESS: "IN_PROGRESS";
  readonly SUCCEEDED: "SUCCEEDED";
  readonly SUCCEEDED_WITH_ISSUES: "SUCCEEDED_WITH_ISSUES";
};
export type UpgradeStatus = (typeof UpgradeStatus)[keyof typeof UpgradeStatus];
export interface UpgradeStepItem {
  UpgradeStep?: UpgradeStep;
  UpgradeStepStatus?: UpgradeStatus;
  Issues?: string[];
  ProgressPercent?: number;
}
export interface UpgradeHistory {
  UpgradeName?: string;
  StartTimestamp?: Date;
  UpgradeStatus?: UpgradeStatus;
  StepsList?: UpgradeStepItem[];
}
export interface GetUpgradeHistoryResponse {
  UpgradeHistories?: UpgradeHistory[];
  NextToken?: string;
}
export interface GetUpgradeStatusRequest {
  DomainName: string | undefined;
}
export interface GetUpgradeStatusResponse {
  UpgradeStep?: UpgradeStep;
  StepStatus?: UpgradeStatus;
  UpgradeName?: string;
}
export interface ListDataSourcesRequest {
  DomainName: string | undefined;
}
export interface DataSourceDetails {
  DataSourceType?: DataSourceType;
  Name?: string;
  Description?: string;
  Status?: DataSourceStatus;
}
export interface ListDataSourcesResponse {
  DataSources?: DataSourceDetails[];
}
export interface ListDomainMaintenancesRequest {
  DomainName: string | undefined;
  Action?: MaintenanceType;
  Status?: MaintenanceStatus;
  MaxResults?: number;
  NextToken?: string;
}
export interface DomainMaintenanceDetails {
  MaintenanceId?: string;
  DomainName?: string;
  Action?: MaintenanceType;
  NodeId?: string;
  Status?: MaintenanceStatus;
  StatusMessage?: string;
  CreatedAt?: Date;
  UpdatedAt?: Date;
}
export interface ListDomainMaintenancesResponse {
  DomainMaintenances?: DomainMaintenanceDetails[];
  NextToken?: string;
}
export declare const EngineType: {
  readonly Elasticsearch: "Elasticsearch";
  readonly OpenSearch: "OpenSearch";
};
export type EngineType = (typeof EngineType)[keyof typeof EngineType];
export interface ListDomainNamesRequest {
  EngineType?: EngineType;
}
export interface DomainInfo {
  DomainName?: string;
  EngineType?: EngineType;
}
export interface ListDomainNamesResponse {
  DomainNames?: DomainInfo[];
}
export interface ListDomainsForPackageRequest {
  PackageID: string | undefined;
  MaxResults?: number;
  NextToken?: string;
}
export interface ListDomainsForPackageResponse {
  DomainPackageDetailsList?: DomainPackageDetails[];
  NextToken?: string;
}
export interface ListInstanceTypeDetailsRequest {
  EngineVersion: string | undefined;
  DomainName?: string;
  MaxResults?: number;
  NextToken?: string;
  RetrieveAZs?: boolean;
  InstanceType?: string;
}
export interface InstanceTypeDetails {
  InstanceType?: OpenSearchPartitionInstanceType;
  EncryptionEnabled?: boolean;
  CognitoEnabled?: boolean;
  AppLogsEnabled?: boolean;
  AdvancedSecurityEnabled?: boolean;
  WarmEnabled?: boolean;
  InstanceRole?: string[];
  AvailabilityZones?: string[];
}
export interface ListInstanceTypeDetailsResponse {
  InstanceTypeDetails?: InstanceTypeDetails[];
  NextToken?: string;
}
export interface ListPackagesForDomainRequest {
  DomainName: string | undefined;
  MaxResults?: number;
  NextToken?: string;
}
export interface ListPackagesForDomainResponse {
  DomainPackageDetailsList?: DomainPackageDetails[];
  NextToken?: string;
}
export interface ListScheduledActionsRequest {
  DomainName: string | undefined;
  MaxResults?: number;
  NextToken?: string;
}
export declare const ScheduledBy: {
  readonly CUSTOMER: "CUSTOMER";
  readonly SYSTEM: "SYSTEM";
};
export type ScheduledBy = (typeof ScheduledBy)[keyof typeof ScheduledBy];
export interface ScheduledAction {
  Id: string | undefined;
  Type: ActionType | undefined;
  Severity: ActionSeverity | undefined;
  ScheduledTime: number | undefined;
  Description?: string;
  ScheduledBy?: ScheduledBy;
  Status?: ActionStatus;
  Mandatory?: boolean;
  Cancellable?: boolean;
}
export interface ListScheduledActionsResponse {
  ScheduledActions?: ScheduledAction[];
  NextToken?: string;
}
export interface ListTagsRequest {
  ARN: string | undefined;
}
export interface ListTagsResponse {
  TagList?: Tag[];
}
export interface ListVersionsRequest {
  MaxResults?: number;
  NextToken?: string;
}
export interface ListVersionsResponse {
  Versions?: string[];
  NextToken?: string;
}
export interface ListVpcEndpointAccessRequest {
  DomainName: string | undefined;
  NextToken?: string;
}
export interface ListVpcEndpointAccessResponse {
  AuthorizedPrincipalList: AuthorizedPrincipal[] | undefined;
  NextToken: string | undefined;
}
export interface ListVpcEndpointsRequest {
  NextToken?: string;
}
export interface ListVpcEndpointsResponse {
  VpcEndpointSummaryList: VpcEndpointSummary[] | undefined;
  NextToken: string | undefined;
}
export interface ListVpcEndpointsForDomainRequest {
  DomainName: string | undefined;
  NextToken?: string;
}
export interface ListVpcEndpointsForDomainResponse {
  VpcEndpointSummaryList: VpcEndpointSummary[] | undefined;
  NextToken: string | undefined;
}
export interface PurchaseReservedInstanceOfferingRequest {
  ReservedInstanceOfferingId: string | undefined;
  ReservationName: string | undefined;
  InstanceCount?: number;
}
export interface PurchaseReservedInstanceOfferingResponse {
  ReservedInstanceId?: string;
  ReservationName?: string;
}
export interface RejectInboundConnectionRequest {
  ConnectionId: string | undefined;
}
export interface RejectInboundConnectionResponse {
  Connection?: InboundConnection;
}
export interface RemoveTagsRequest {
  ARN: string | undefined;
  TagKeys: string[] | undefined;
}
export interface RevokeVpcEndpointAccessRequest {
  DomainName: string | undefined;
  Account: string | undefined;
}
export interface RevokeVpcEndpointAccessResponse {}
export interface StartDomainMaintenanceRequest {
  DomainName: string | undefined;
  Action: MaintenanceType | undefined;
  NodeId?: string;
}
export interface StartDomainMaintenanceResponse {
  MaintenanceId?: string;
}
export declare const ScheduleAt: {
  readonly NOW: "NOW";
  readonly OFF_PEAK_WINDOW: "OFF_PEAK_WINDOW";
  readonly TIMESTAMP: "TIMESTAMP";
};
export type ScheduleAt = (typeof ScheduleAt)[keyof typeof ScheduleAt];
export interface StartServiceSoftwareUpdateRequest {
  DomainName: string | undefined;
  ScheduleAt?: ScheduleAt;
  DesiredStartTime?: number;
}
export interface StartServiceSoftwareUpdateResponse {
  ServiceSoftwareOptions?: ServiceSoftwareOptions;
}
export interface UpdateDataSourceRequest {
  DomainName: string | undefined;
  Name: string | undefined;
  DataSourceType: DataSourceType | undefined;
  Description?: string;
  Status?: DataSourceStatus;
}
export interface UpdateDataSourceResponse {
  Message?: string;
}
export declare const DryRunMode: {
  readonly Basic: "Basic";
  readonly Verbose: "Verbose";
};
export type DryRunMode = (typeof DryRunMode)[keyof typeof DryRunMode];
export interface UpdateDomainConfigRequest {
  DomainName: string | undefined;
  ClusterConfig?: ClusterConfig;
  EBSOptions?: EBSOptions;
  SnapshotOptions?: SnapshotOptions;
  VPCOptions?: VPCOptions;
  CognitoOptions?: CognitoOptions;
  AdvancedOptions?: Record<string, string>;
  AccessPolicies?: string;
  IPAddressType?: IPAddressType;
  LogPublishingOptions?: Partial<Record<LogType, LogPublishingOption>>;
  EncryptionAtRestOptions?: EncryptionAtRestOptions;
  DomainEndpointOptions?: DomainEndpointOptions;
  NodeToNodeEncryptionOptions?: NodeToNodeEncryptionOptions;
  AdvancedSecurityOptions?: AdvancedSecurityOptionsInput;
  AutoTuneOptions?: AutoTuneOptions;
  DryRun?: boolean;
  DryRunMode?: DryRunMode;
  OffPeakWindowOptions?: OffPeakWindowOptions;
  SoftwareUpdateOptions?: SoftwareUpdateOptions;
}
export interface UpdateDomainConfigResponse {
  DomainConfig: DomainConfig | undefined;
  DryRunResults?: DryRunResults;
  DryRunProgressStatus?: DryRunProgressStatus;
}
export interface UpdatePackageRequest {
  PackageID: string | undefined;
  PackageSource: PackageSource | undefined;
  PackageDescription?: string;
  CommitMessage?: string;
}
export interface UpdatePackageResponse {
  PackageDetails?: PackageDetails;
}
export declare class SlotNotAvailableException extends __BaseException {
  readonly name: "SlotNotAvailableException";
  readonly $fault: "client";
  SlotSuggestions?: number[];
  constructor(
    opts: __ExceptionOptionType<SlotNotAvailableException, __BaseException>
  );
}
export interface UpdateScheduledActionRequest {
  DomainName: string | undefined;
  ActionID: string | undefined;
  ActionType: ActionType | undefined;
  ScheduleAt: ScheduleAt | undefined;
  DesiredStartTime?: number;
}
export interface UpdateScheduledActionResponse {
  ScheduledAction?: ScheduledAction;
}
export interface UpdateVpcEndpointRequest {
  VpcEndpointId: string | undefined;
  VpcOptions: VPCOptions | undefined;
}
export interface UpdateVpcEndpointResponse {
  VpcEndpoint: VpcEndpoint | undefined;
}
export interface UpgradeDomainRequest {
  DomainName: string | undefined;
  TargetVersion: string | undefined;
  PerformCheckOnly?: boolean;
  AdvancedOptions?: Record<string, string>;
}
export interface UpgradeDomainResponse {
  UpgradeId?: string;
  DomainName?: string;
  TargetVersion?: string;
  PerformCheckOnly?: boolean;
  AdvancedOptions?: Record<string, string>;
  ChangeProgressDetails?: ChangeProgressDetails;
}
export declare const MasterUserOptionsFilterSensitiveLog: (
  obj: MasterUserOptions
) => any;
export declare const SAMLOptionsInputFilterSensitiveLog: (
  obj: SAMLOptionsInput
) => any;
export declare const AdvancedSecurityOptionsInputFilterSensitiveLog: (
  obj: AdvancedSecurityOptionsInput
) => any;
export declare const CreateDomainRequestFilterSensitiveLog: (
  obj: CreateDomainRequest
) => any;
export declare const UpdateDomainConfigRequestFilterSensitiveLog: (
  obj: UpdateDomainConfigRequest
) => any;
